# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .provider import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_azure.advisor as advisor
    import pulumi_azure.analysisservices as analysisservices
    import pulumi_azure.apimanagement as apimanagement
    import pulumi_azure.appconfiguration as appconfiguration
    import pulumi_azure.appinsights as appinsights
    import pulumi_azure.appplatform as appplatform
    import pulumi_azure.appservice as appservice
    import pulumi_azure.attestation as attestation
    import pulumi_azure.authorization as authorization
    import pulumi_azure.automation as automation
    import pulumi_azure.avs as avs
    import pulumi_azure.backup as backup
    import pulumi_azure.batch as batch
    import pulumi_azure.billing as billing
    import pulumi_azure.blueprint as blueprint
    import pulumi_azure.bot as bot
    import pulumi_azure.cdn as cdn
    import pulumi_azure.cognitive as cognitive
    import pulumi_azure.communication as communication
    import pulumi_azure.compute as compute
    import pulumi_azure.config as config
    import pulumi_azure.consumption as consumption
    import pulumi_azure.containerservice as containerservice
    import pulumi_azure.core as core
    import pulumi_azure.cosmosdb as cosmosdb
    import pulumi_azure.costmanagement as costmanagement
    import pulumi_azure.dashboard as dashboard
    import pulumi_azure.databasemigration as databasemigration
    import pulumi_azure.databoxedge as databoxedge
    import pulumi_azure.databricks as databricks
    import pulumi_azure.datafactory as datafactory
    import pulumi_azure.datalake as datalake
    import pulumi_azure.datashare as datashare
    import pulumi_azure.desktopvirtualization as desktopvirtualization
    import pulumi_azure.devspace as devspace
    import pulumi_azure.devtest as devtest
    import pulumi_azure.digitaltwins as digitaltwins
    import pulumi_azure.dns as dns
    import pulumi_azure.eventgrid as eventgrid
    import pulumi_azure.eventhub as eventhub
    import pulumi_azure.frontdoor as frontdoor
    import pulumi_azure.hdinsight as hdinsight
    import pulumi_azure.healthcare as healthcare
    import pulumi_azure.hpc as hpc
    import pulumi_azure.hsm as hsm
    import pulumi_azure.iot as iot
    import pulumi_azure.iotcentral as iotcentral
    import pulumi_azure.keyvault as keyvault
    import pulumi_azure.kusto as kusto
    import pulumi_azure.lb as lb
    import pulumi_azure.lighthouse as lighthouse
    import pulumi_azure.loganalytics as loganalytics
    import pulumi_azure.logicapps as logicapps
    import pulumi_azure.machinelearning as machinelearning
    import pulumi_azure.maintenance as maintenance
    import pulumi_azure.managedapplication as managedapplication
    import pulumi_azure.management as management
    import pulumi_azure.managementgroups as managementgroups
    import pulumi_azure.managementresource as managementresource
    import pulumi_azure.maps as maps
    import pulumi_azure.mariadb as mariadb
    import pulumi_azure.marketplace as marketplace
    import pulumi_azure.media as media
    import pulumi_azure.mediaservices as mediaservices
    import pulumi_azure.mixedreality as mixedreality
    import pulumi_azure.monitoring as monitoring
    import pulumi_azure.msi as msi
    import pulumi_azure.mssql as mssql
    import pulumi_azure.mysql as mysql
    import pulumi_azure.netapp as netapp
    import pulumi_azure.network as network
    import pulumi_azure.notificationhub as notificationhub
    import pulumi_azure.operationalinsights as operationalinsights
    import pulumi_azure.policy as policy
    import pulumi_azure.postgresql as postgresql
    import pulumi_azure.powerbi as powerbi
    import pulumi_azure.privatedns as privatedns
    import pulumi_azure.privatelink as privatelink
    import pulumi_azure.proximity as proximity
    import pulumi_azure.purview as purview
    import pulumi_azure.recoveryservices as recoveryservices
    import pulumi_azure.redis as redis
    import pulumi_azure.relay as relay
    import pulumi_azure.role as role
    import pulumi_azure.search as search
    import pulumi_azure.securitycenter as securitycenter
    import pulumi_azure.sentinel as sentinel
    import pulumi_azure.servicebus as servicebus
    import pulumi_azure.servicefabric as servicefabric
    import pulumi_azure.signalr as signalr
    import pulumi_azure.siterecovery as siterecovery
    import pulumi_azure.sql as sql
    import pulumi_azure.stack as stack
    import pulumi_azure.storage as storage
    import pulumi_azure.streamanalytics as streamanalytics
    import pulumi_azure.synapse as synapse
    import pulumi_azure.trafficmanager as trafficmanager
    import pulumi_azure.waf as waf
else:
    advisor = _utilities.lazy_import('pulumi_azure.advisor')
    analysisservices = _utilities.lazy_import('pulumi_azure.analysisservices')
    apimanagement = _utilities.lazy_import('pulumi_azure.apimanagement')
    appconfiguration = _utilities.lazy_import('pulumi_azure.appconfiguration')
    appinsights = _utilities.lazy_import('pulumi_azure.appinsights')
    appplatform = _utilities.lazy_import('pulumi_azure.appplatform')
    appservice = _utilities.lazy_import('pulumi_azure.appservice')
    attestation = _utilities.lazy_import('pulumi_azure.attestation')
    authorization = _utilities.lazy_import('pulumi_azure.authorization')
    automation = _utilities.lazy_import('pulumi_azure.automation')
    avs = _utilities.lazy_import('pulumi_azure.avs')
    backup = _utilities.lazy_import('pulumi_azure.backup')
    batch = _utilities.lazy_import('pulumi_azure.batch')
    billing = _utilities.lazy_import('pulumi_azure.billing')
    blueprint = _utilities.lazy_import('pulumi_azure.blueprint')
    bot = _utilities.lazy_import('pulumi_azure.bot')
    cdn = _utilities.lazy_import('pulumi_azure.cdn')
    cognitive = _utilities.lazy_import('pulumi_azure.cognitive')
    communication = _utilities.lazy_import('pulumi_azure.communication')
    compute = _utilities.lazy_import('pulumi_azure.compute')
    config = _utilities.lazy_import('pulumi_azure.config')
    consumption = _utilities.lazy_import('pulumi_azure.consumption')
    containerservice = _utilities.lazy_import('pulumi_azure.containerservice')
    core = _utilities.lazy_import('pulumi_azure.core')
    cosmosdb = _utilities.lazy_import('pulumi_azure.cosmosdb')
    costmanagement = _utilities.lazy_import('pulumi_azure.costmanagement')
    dashboard = _utilities.lazy_import('pulumi_azure.dashboard')
    databasemigration = _utilities.lazy_import('pulumi_azure.databasemigration')
    databoxedge = _utilities.lazy_import('pulumi_azure.databoxedge')
    databricks = _utilities.lazy_import('pulumi_azure.databricks')
    datafactory = _utilities.lazy_import('pulumi_azure.datafactory')
    datalake = _utilities.lazy_import('pulumi_azure.datalake')
    datashare = _utilities.lazy_import('pulumi_azure.datashare')
    desktopvirtualization = _utilities.lazy_import('pulumi_azure.desktopvirtualization')
    devspace = _utilities.lazy_import('pulumi_azure.devspace')
    devtest = _utilities.lazy_import('pulumi_azure.devtest')
    digitaltwins = _utilities.lazy_import('pulumi_azure.digitaltwins')
    dns = _utilities.lazy_import('pulumi_azure.dns')
    eventgrid = _utilities.lazy_import('pulumi_azure.eventgrid')
    eventhub = _utilities.lazy_import('pulumi_azure.eventhub')
    frontdoor = _utilities.lazy_import('pulumi_azure.frontdoor')
    hdinsight = _utilities.lazy_import('pulumi_azure.hdinsight')
    healthcare = _utilities.lazy_import('pulumi_azure.healthcare')
    hpc = _utilities.lazy_import('pulumi_azure.hpc')
    hsm = _utilities.lazy_import('pulumi_azure.hsm')
    iot = _utilities.lazy_import('pulumi_azure.iot')
    iotcentral = _utilities.lazy_import('pulumi_azure.iotcentral')
    keyvault = _utilities.lazy_import('pulumi_azure.keyvault')
    kusto = _utilities.lazy_import('pulumi_azure.kusto')
    lb = _utilities.lazy_import('pulumi_azure.lb')
    lighthouse = _utilities.lazy_import('pulumi_azure.lighthouse')
    loganalytics = _utilities.lazy_import('pulumi_azure.loganalytics')
    logicapps = _utilities.lazy_import('pulumi_azure.logicapps')
    machinelearning = _utilities.lazy_import('pulumi_azure.machinelearning')
    maintenance = _utilities.lazy_import('pulumi_azure.maintenance')
    managedapplication = _utilities.lazy_import('pulumi_azure.managedapplication')
    management = _utilities.lazy_import('pulumi_azure.management')
    managementgroups = _utilities.lazy_import('pulumi_azure.managementgroups')
    managementresource = _utilities.lazy_import('pulumi_azure.managementresource')
    maps = _utilities.lazy_import('pulumi_azure.maps')
    mariadb = _utilities.lazy_import('pulumi_azure.mariadb')
    marketplace = _utilities.lazy_import('pulumi_azure.marketplace')
    media = _utilities.lazy_import('pulumi_azure.media')
    mediaservices = _utilities.lazy_import('pulumi_azure.mediaservices')
    mixedreality = _utilities.lazy_import('pulumi_azure.mixedreality')
    monitoring = _utilities.lazy_import('pulumi_azure.monitoring')
    msi = _utilities.lazy_import('pulumi_azure.msi')
    mssql = _utilities.lazy_import('pulumi_azure.mssql')
    mysql = _utilities.lazy_import('pulumi_azure.mysql')
    netapp = _utilities.lazy_import('pulumi_azure.netapp')
    network = _utilities.lazy_import('pulumi_azure.network')
    notificationhub = _utilities.lazy_import('pulumi_azure.notificationhub')
    operationalinsights = _utilities.lazy_import('pulumi_azure.operationalinsights')
    policy = _utilities.lazy_import('pulumi_azure.policy')
    postgresql = _utilities.lazy_import('pulumi_azure.postgresql')
    powerbi = _utilities.lazy_import('pulumi_azure.powerbi')
    privatedns = _utilities.lazy_import('pulumi_azure.privatedns')
    privatelink = _utilities.lazy_import('pulumi_azure.privatelink')
    proximity = _utilities.lazy_import('pulumi_azure.proximity')
    purview = _utilities.lazy_import('pulumi_azure.purview')
    recoveryservices = _utilities.lazy_import('pulumi_azure.recoveryservices')
    redis = _utilities.lazy_import('pulumi_azure.redis')
    relay = _utilities.lazy_import('pulumi_azure.relay')
    role = _utilities.lazy_import('pulumi_azure.role')
    search = _utilities.lazy_import('pulumi_azure.search')
    securitycenter = _utilities.lazy_import('pulumi_azure.securitycenter')
    sentinel = _utilities.lazy_import('pulumi_azure.sentinel')
    servicebus = _utilities.lazy_import('pulumi_azure.servicebus')
    servicefabric = _utilities.lazy_import('pulumi_azure.servicefabric')
    signalr = _utilities.lazy_import('pulumi_azure.signalr')
    siterecovery = _utilities.lazy_import('pulumi_azure.siterecovery')
    sql = _utilities.lazy_import('pulumi_azure.sql')
    stack = _utilities.lazy_import('pulumi_azure.stack')
    storage = _utilities.lazy_import('pulumi_azure.storage')
    streamanalytics = _utilities.lazy_import('pulumi_azure.streamanalytics')
    synapse = _utilities.lazy_import('pulumi_azure.synapse')
    trafficmanager = _utilities.lazy_import('pulumi_azure.trafficmanager')
    waf = _utilities.lazy_import('pulumi_azure.waf')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "azure",
  "mod": "analysisservices/server",
  "fqn": "pulumi_azure.analysisservices",
  "classes": {
   "azure:analysisservices/server:Server": "Server"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/api",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/api:Api": "Api"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/apiDiagnostic",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/apiDiagnostic:ApiDiagnostic": "ApiDiagnostic"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/apiOperation",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/apiOperation:ApiOperation": "ApiOperation"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/apiOperationPolicy",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/apiOperationPolicy:ApiOperationPolicy": "ApiOperationPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/apiPolicy",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/apiPolicy:ApiPolicy": "ApiPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/apiSchema",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/apiSchema:ApiSchema": "ApiSchema"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/apiVersionSet",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/apiVersionSet:ApiVersionSet": "ApiVersionSet"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/authorizationServer",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/authorizationServer:AuthorizationServer": "AuthorizationServer"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/backend",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/backend:Backend": "Backend"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/certificate",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/customDomain",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/customDomain:CustomDomain": "CustomDomain"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/diagnostic",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/diagnostic:Diagnostic": "Diagnostic"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/emailTemplate",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/emailTemplate:EmailTemplate": "EmailTemplate"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/group",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/group:Group": "Group"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/groupUser",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/groupUser:GroupUser": "GroupUser"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/identityProviderAad",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/identityProviderAad:IdentityProviderAad": "IdentityProviderAad"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/identityProviderAadb2c",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/identityProviderAadb2c:IdentityProviderAadb2c": "IdentityProviderAadb2c"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/identityProviderFacebook",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/identityProviderFacebook:IdentityProviderFacebook": "IdentityProviderFacebook"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/identityProviderGoogle",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/identityProviderGoogle:IdentityProviderGoogle": "IdentityProviderGoogle"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/identityProviderMicrosoft",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/identityProviderMicrosoft:IdentityProviderMicrosoft": "IdentityProviderMicrosoft"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/identityProviderTwitter",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/identityProviderTwitter:IdentityProviderTwitter": "IdentityProviderTwitter"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/logger",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/logger:Logger": "Logger"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/namedValue",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/namedValue:NamedValue": "NamedValue"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/openIdConnectProvider",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/openIdConnectProvider:OpenIdConnectProvider": "OpenIdConnectProvider"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/policy",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/product",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/product:Product": "Product"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/productApi",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/productApi:ProductApi": "ProductApi"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/productGroup",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/productGroup:ProductGroup": "ProductGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/productPolicy",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/productPolicy:ProductPolicy": "ProductPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/property",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/property:Property": "Property"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/service",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/service:Service": "Service"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/subscription",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/subscription:Subscription": "Subscription"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/user",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/user:User": "User"
  }
 },
 {
  "pkg": "azure",
  "mod": "appconfiguration/configurationStore",
  "fqn": "pulumi_azure.appconfiguration",
  "classes": {
   "azure:appconfiguration/configurationStore:ConfigurationStore": "ConfigurationStore"
  }
 },
 {
  "pkg": "azure",
  "mod": "appinsights/analyticsItem",
  "fqn": "pulumi_azure.appinsights",
  "classes": {
   "azure:appinsights/analyticsItem:AnalyticsItem": "AnalyticsItem"
  }
 },
 {
  "pkg": "azure",
  "mod": "appinsights/apiKey",
  "fqn": "pulumi_azure.appinsights",
  "classes": {
   "azure:appinsights/apiKey:ApiKey": "ApiKey"
  }
 },
 {
  "pkg": "azure",
  "mod": "appinsights/insights",
  "fqn": "pulumi_azure.appinsights",
  "classes": {
   "azure:appinsights/insights:Insights": "Insights"
  }
 },
 {
  "pkg": "azure",
  "mod": "appinsights/smartDetectionRule",
  "fqn": "pulumi_azure.appinsights",
  "classes": {
   "azure:appinsights/smartDetectionRule:SmartDetectionRule": "SmartDetectionRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "appinsights/webTest",
  "fqn": "pulumi_azure.appinsights",
  "classes": {
   "azure:appinsights/webTest:WebTest": "WebTest"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudActiveDeployment",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudActiveDeployment:SpringCloudActiveDeployment": "SpringCloudActiveDeployment"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudApp",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudApp:SpringCloudApp": "SpringCloudApp"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudAppCosmosDBAssociation",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudAppCosmosDBAssociation:SpringCloudAppCosmosDBAssociation": "SpringCloudAppCosmosDBAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudAppMysqlAssociation",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudAppMysqlAssociation:SpringCloudAppMysqlAssociation": "SpringCloudAppMysqlAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudAppRedisAssociation",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudAppRedisAssociation:SpringCloudAppRedisAssociation": "SpringCloudAppRedisAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudCertificate",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudCertificate:SpringCloudCertificate": "SpringCloudCertificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudCustomDomain",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudCustomDomain:SpringCloudCustomDomain": "SpringCloudCustomDomain"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudJavaDeployment",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudJavaDeployment:SpringCloudJavaDeployment": "SpringCloudJavaDeployment"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudService",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudService:SpringCloudService": "SpringCloudService"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/activeSlot",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/activeSlot:ActiveSlot": "ActiveSlot"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/appService",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/appService:AppService": "AppService"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/certificate",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/certificateBinding",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/certificateBinding:CertificateBinding": "CertificateBinding"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/certificateOrder",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/certificateOrder:CertificateOrder": "CertificateOrder"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/customHostnameBinding",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/customHostnameBinding:CustomHostnameBinding": "CustomHostnameBinding"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/environment",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/environment:Environment": "Environment"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/environmentV3",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/environmentV3:EnvironmentV3": "EnvironmentV3"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/functionApp",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/functionApp:FunctionApp": "FunctionApp"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/functionAppSlot",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/functionAppSlot:FunctionAppSlot": "FunctionAppSlot"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/hybridConnection",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/hybridConnection:HybridConnection": "HybridConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/managedCertificate",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/managedCertificate:ManagedCertificate": "ManagedCertificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/plan",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/plan:Plan": "Plan"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/slot",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/slot:Slot": "Slot"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/slotVirtualNetworkSwiftConnection",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/slotVirtualNetworkSwiftConnection:SlotVirtualNetworkSwiftConnection": "SlotVirtualNetworkSwiftConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/sourceCodeToken",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/sourceCodeToken:SourceCodeToken": "SourceCodeToken"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/staticSite",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/staticSite:StaticSite": "StaticSite"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/virtualNetworkSwiftConnection",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/virtualNetworkSwiftConnection:VirtualNetworkSwiftConnection": "VirtualNetworkSwiftConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "attestation/provider",
  "fqn": "pulumi_azure.attestation",
  "classes": {
   "azure:attestation/provider:Provider": "Provider"
  }
 },
 {
  "pkg": "azure",
  "mod": "authorization/assignment",
  "fqn": "pulumi_azure.authorization",
  "classes": {
   "azure:authorization/assignment:Assignment": "Assignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "authorization/roleDefinition",
  "fqn": "pulumi_azure.authorization",
  "classes": {
   "azure:authorization/roleDefinition:RoleDefinition": "RoleDefinition"
  }
 },
 {
  "pkg": "azure",
  "mod": "authorization/userAssignedIdentity",
  "fqn": "pulumi_azure.authorization",
  "classes": {
   "azure:authorization/userAssignedIdentity:UserAssignedIdentity": "UserAssignedIdentity"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/account",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/account:Account": "Account"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/boolVariable",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/boolVariable:BoolVariable": "BoolVariable"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/certificate",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/connection",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/connectionCertificate",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/connectionCertificate:ConnectionCertificate": "ConnectionCertificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/connectionClassicCertificate",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/connectionClassicCertificate:ConnectionClassicCertificate": "ConnectionClassicCertificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/connectionServicePrincipal",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/connectionServicePrincipal:ConnectionServicePrincipal": "ConnectionServicePrincipal"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/credential",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/credential:Credential": "Credential"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/dateTimeVariable",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/dateTimeVariable:DateTimeVariable": "DateTimeVariable"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/dscConfiguration",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/dscConfiguration:DscConfiguration": "DscConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/dscNodeConfiguration",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/dscNodeConfiguration:DscNodeConfiguration": "DscNodeConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/intVariable",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/intVariable:IntVariable": "IntVariable"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/jobSchedule",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/jobSchedule:JobSchedule": "JobSchedule"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/module",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/module:Module": "Module"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/runBook",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/runBook:RunBook": "RunBook"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/schedule",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/schedule:Schedule": "Schedule"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/stringVariable",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/stringVariable:StringVariable": "StringVariable"
  }
 },
 {
  "pkg": "azure",
  "mod": "avs/cluster",
  "fqn": "pulumi_azure.avs",
  "classes": {
   "azure:avs/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "avs/privateCloud",
  "fqn": "pulumi_azure.avs",
  "classes": {
   "azure:avs/privateCloud:PrivateCloud": "PrivateCloud"
  }
 },
 {
  "pkg": "azure",
  "mod": "backup/containerStorageAccount",
  "fqn": "pulumi_azure.backup",
  "classes": {
   "azure:backup/containerStorageAccount:ContainerStorageAccount": "ContainerStorageAccount"
  }
 },
 {
  "pkg": "azure",
  "mod": "backup/policyFileShare",
  "fqn": "pulumi_azure.backup",
  "classes": {
   "azure:backup/policyFileShare:PolicyFileShare": "PolicyFileShare"
  }
 },
 {
  "pkg": "azure",
  "mod": "backup/policyVM",
  "fqn": "pulumi_azure.backup",
  "classes": {
   "azure:backup/policyVM:PolicyVM": "PolicyVM"
  }
 },
 {
  "pkg": "azure",
  "mod": "backup/protectedFileShare",
  "fqn": "pulumi_azure.backup",
  "classes": {
   "azure:backup/protectedFileShare:ProtectedFileShare": "ProtectedFileShare"
  }
 },
 {
  "pkg": "azure",
  "mod": "backup/protectedVM",
  "fqn": "pulumi_azure.backup",
  "classes": {
   "azure:backup/protectedVM:ProtectedVM": "ProtectedVM"
  }
 },
 {
  "pkg": "azure",
  "mod": "batch/account",
  "fqn": "pulumi_azure.batch",
  "classes": {
   "azure:batch/account:Account": "Account"
  }
 },
 {
  "pkg": "azure",
  "mod": "batch/application",
  "fqn": "pulumi_azure.batch",
  "classes": {
   "azure:batch/application:Application": "Application"
  }
 },
 {
  "pkg": "azure",
  "mod": "batch/certificate",
  "fqn": "pulumi_azure.batch",
  "classes": {
   "azure:batch/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "batch/pool",
  "fqn": "pulumi_azure.batch",
  "classes": {
   "azure:batch/pool:Pool": "Pool"
  }
 },
 {
  "pkg": "azure",
  "mod": "blueprint/assignment",
  "fqn": "pulumi_azure.blueprint",
  "classes": {
   "azure:blueprint/assignment:Assignment": "Assignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "bot/channelDirectLine",
  "fqn": "pulumi_azure.bot",
  "classes": {
   "azure:bot/channelDirectLine:ChannelDirectLine": "ChannelDirectLine"
  }
 },
 {
  "pkg": "azure",
  "mod": "bot/channelEmail",
  "fqn": "pulumi_azure.bot",
  "classes": {
   "azure:bot/channelEmail:ChannelEmail": "ChannelEmail"
  }
 },
 {
  "pkg": "azure",
  "mod": "bot/channelSlack",
  "fqn": "pulumi_azure.bot",
  "classes": {
   "azure:bot/channelSlack:ChannelSlack": "ChannelSlack"
  }
 },
 {
  "pkg": "azure",
  "mod": "bot/channelTeams",
  "fqn": "pulumi_azure.bot",
  "classes": {
   "azure:bot/channelTeams:ChannelTeams": "ChannelTeams"
  }
 },
 {
  "pkg": "azure",
  "mod": "bot/channelsRegistration",
  "fqn": "pulumi_azure.bot",
  "classes": {
   "azure:bot/channelsRegistration:ChannelsRegistration": "ChannelsRegistration"
  }
 },
 {
  "pkg": "azure",
  "mod": "bot/connection",
  "fqn": "pulumi_azure.bot",
  "classes": {
   "azure:bot/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "azure",
  "mod": "bot/webApp",
  "fqn": "pulumi_azure.bot",
  "classes": {
   "azure:bot/webApp:WebApp": "WebApp"
  }
 },
 {
  "pkg": "azure",
  "mod": "cdn/endpoint",
  "fqn": "pulumi_azure.cdn",
  "classes": {
   "azure:cdn/endpoint:Endpoint": "Endpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "cdn/profile",
  "fqn": "pulumi_azure.cdn",
  "classes": {
   "azure:cdn/profile:Profile": "Profile"
  }
 },
 {
  "pkg": "azure",
  "mod": "cognitive/account",
  "fqn": "pulumi_azure.cognitive",
  "classes": {
   "azure:cognitive/account:Account": "Account"
  }
 },
 {
  "pkg": "azure",
  "mod": "communication/service",
  "fqn": "pulumi_azure.communication",
  "classes": {
   "azure:communication/service:Service": "Service"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/availabilitySet",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/availabilitySet:AvailabilitySet": "AvailabilitySet"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/bastionHost",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/bastionHost:BastionHost": "BastionHost"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/configurationPolicyAssignment",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/configurationPolicyAssignment:ConfigurationPolicyAssignment": "ConfigurationPolicyAssignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/dataDiskAttachment",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/dataDiskAttachment:DataDiskAttachment": "DataDiskAttachment"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/dedicatedHost",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/dedicatedHost:DedicatedHost": "DedicatedHost"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/dedicatedHostGroup",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/dedicatedHostGroup:DedicatedHostGroup": "DedicatedHostGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/diskAccess",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/diskAccess:DiskAccess": "DiskAccess"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/diskEncryptionSet",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/diskEncryptionSet:DiskEncryptionSet": "DiskEncryptionSet"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/extension",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/extension:Extension": "Extension"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/image",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/image:Image": "Image"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/linuxVirtualMachine",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/linuxVirtualMachine:LinuxVirtualMachine": "LinuxVirtualMachine"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/linuxVirtualMachineScaleSet",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/linuxVirtualMachineScaleSet:LinuxVirtualMachineScaleSet": "LinuxVirtualMachineScaleSet"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/managedDisk",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/managedDisk:ManagedDisk": "ManagedDisk"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/orchestratedVirtualMachineScaleSet",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/orchestratedVirtualMachineScaleSet:OrchestratedVirtualMachineScaleSet": "OrchestratedVirtualMachineScaleSet"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/scaleSet",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/scaleSet:ScaleSet": "ScaleSet"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/sharedImage",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/sharedImage:SharedImage": "SharedImage"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/sharedImageGallery",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/sharedImageGallery:SharedImageGallery": "SharedImageGallery"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/sharedImageVersion",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/sharedImageVersion:SharedImageVersion": "SharedImageVersion"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/snapshot",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/sshPublicKey",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/sshPublicKey:SshPublicKey": "SshPublicKey"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/virtualMachine",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/virtualMachine:VirtualMachine": "VirtualMachine"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/virtualMachineScaleSetExtension",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/virtualMachineScaleSetExtension:VirtualMachineScaleSetExtension": "VirtualMachineScaleSetExtension"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/windowsVirtualMachine",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/windowsVirtualMachine:WindowsVirtualMachine": "WindowsVirtualMachine"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/windowsVirtualMachineScaleSet",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/windowsVirtualMachineScaleSet:WindowsVirtualMachineScaleSet": "WindowsVirtualMachineScaleSet"
  }
 },
 {
  "pkg": "azure",
  "mod": "consumption/budgetResourceGroup",
  "fqn": "pulumi_azure.consumption",
  "classes": {
   "azure:consumption/budgetResourceGroup:BudgetResourceGroup": "BudgetResourceGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "consumption/budgetSubscription",
  "fqn": "pulumi_azure.consumption",
  "classes": {
   "azure:consumption/budgetSubscription:BudgetSubscription": "BudgetSubscription"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/group",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/group:Group": "Group"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/kubernetesCluster",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/kubernetesCluster:KubernetesCluster": "KubernetesCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/kubernetesClusterNodePool",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/kubernetesClusterNodePool:KubernetesClusterNodePool": "KubernetesClusterNodePool"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/registry",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/registry:Registry": "Registry"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/registryScopeMap",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/registryScopeMap:RegistryScopeMap": "RegistryScopeMap"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/registryToken",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/registryToken:RegistryToken": "RegistryToken"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/registryWebhook",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/registryWebhook:RegistryWebhook": "RegistryWebhook"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/registryWebook",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/registryWebook:RegistryWebook": "RegistryWebook"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/customProvider",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/customProvider:CustomProvider": "CustomProvider"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/resourceGroup",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/resourceGroup:ResourceGroup": "ResourceGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/resourceGroupTemplateDeployment",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/resourceGroupTemplateDeployment:ResourceGroupTemplateDeployment": "ResourceGroupTemplateDeployment"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/resourceProviderRegistration",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/resourceProviderRegistration:ResourceProviderRegistration": "ResourceProviderRegistration"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/subscription",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/subscription:Subscription": "Subscription"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/subscriptionTemplateDeployment",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/subscriptionTemplateDeployment:SubscriptionTemplateDeployment": "SubscriptionTemplateDeployment"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/templateDeployment",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/templateDeployment:TemplateDeployment": "TemplateDeployment"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/tenantTemplateDeployment",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/tenantTemplateDeployment:TenantTemplateDeployment": "TenantTemplateDeployment"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/account",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/account:Account": "Account"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/cassandraKeyspace",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/cassandraKeyspace:CassandraKeyspace": "CassandraKeyspace"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/cassandraTable",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/cassandraTable:CassandraTable": "CassandraTable"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/gremlinDatabase",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/gremlinDatabase:GremlinDatabase": "GremlinDatabase"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/gremlinGraph",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/gremlinGraph:GremlinGraph": "GremlinGraph"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/mongoCollection",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/mongoCollection:MongoCollection": "MongoCollection"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/mongoDatabase",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/mongoDatabase:MongoDatabase": "MongoDatabase"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/notebookWorkspace",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/notebookWorkspace:NotebookWorkspace": "NotebookWorkspace"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/sqlContainer",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/sqlContainer:SqlContainer": "SqlContainer"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/sqlDatabase",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/sqlDatabase:SqlDatabase": "SqlDatabase"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/sqlFunction",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/sqlFunction:SqlFunction": "SqlFunction"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/sqlStoredProcedure",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/sqlStoredProcedure:SqlStoredProcedure": "SqlStoredProcedure"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/sqlTrigger",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/sqlTrigger:SqlTrigger": "SqlTrigger"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/table",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/table:Table": "Table"
  }
 },
 {
  "pkg": "azure",
  "mod": "costmanagement/resourceGroupExport",
  "fqn": "pulumi_azure.costmanagement",
  "classes": {
   "azure:costmanagement/resourceGroupExport:ResourceGroupExport": "ResourceGroupExport"
  }
 },
 {
  "pkg": "azure",
  "mod": "dashboard/dashboard",
  "fqn": "pulumi_azure.dashboard",
  "classes": {
   "azure:dashboard/dashboard:Dashboard": "Dashboard"
  }
 },
 {
  "pkg": "azure",
  "mod": "databasemigration/project",
  "fqn": "pulumi_azure.databasemigration",
  "classes": {
   "azure:databasemigration/project:Project": "Project"
  }
 },
 {
  "pkg": "azure",
  "mod": "databasemigration/service",
  "fqn": "pulumi_azure.databasemigration",
  "classes": {
   "azure:databasemigration/service:Service": "Service"
  }
 },
 {
  "pkg": "azure",
  "mod": "databoxedge/device",
  "fqn": "pulumi_azure.databoxedge",
  "classes": {
   "azure:databoxedge/device:Device": "Device"
  }
 },
 {
  "pkg": "azure",
  "mod": "databoxedge/order",
  "fqn": "pulumi_azure.databoxedge",
  "classes": {
   "azure:databoxedge/order:Order": "Order"
  }
 },
 {
  "pkg": "azure",
  "mod": "databricks/workspace",
  "fqn": "pulumi_azure.databricks",
  "classes": {
   "azure:databricks/workspace:Workspace": "Workspace"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/datasetAzureBlob",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/datasetAzureBlob:DatasetAzureBlob": "DatasetAzureBlob"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/datasetCosmosDBApi",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/datasetCosmosDBApi:DatasetCosmosDBApi": "DatasetCosmosDBApi"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/datasetDelimitedText",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/datasetDelimitedText:DatasetDelimitedText": "DatasetDelimitedText"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/datasetHttp",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/datasetHttp:DatasetHttp": "DatasetHttp"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/datasetJson",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/datasetJson:DatasetJson": "DatasetJson"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/datasetMysql",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/datasetMysql:DatasetMysql": "DatasetMysql"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/datasetParquet",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/datasetParquet:DatasetParquet": "DatasetParquet"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/datasetPostgresql",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/datasetPostgresql:DatasetPostgresql": "DatasetPostgresql"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/datasetSnowflake",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/datasetSnowflake:DatasetSnowflake": "DatasetSnowflake"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/datasetSqlServerTable",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/datasetSqlServerTable:DatasetSqlServerTable": "DatasetSqlServerTable"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/factory",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/factory:Factory": "Factory"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/integrationRuntimeManaged",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/integrationRuntimeManaged:IntegrationRuntimeManaged": "IntegrationRuntimeManaged"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/integrationRuntimeRule",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/integrationRuntimeRule:IntegrationRuntimeRule": "IntegrationRuntimeRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/integrationRuntimeSelfHosted",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/integrationRuntimeSelfHosted:IntegrationRuntimeSelfHosted": "IntegrationRuntimeSelfHosted"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/integrationRuntimeSsis",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/integrationRuntimeSsis:IntegrationRuntimeSsis": "IntegrationRuntimeSsis"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceAzureBlobStorage",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceAzureBlobStorage:LinkedServiceAzureBlobStorage": "LinkedServiceAzureBlobStorage"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceAzureDatabricks",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceAzureDatabricks:LinkedServiceAzureDatabricks": "LinkedServiceAzureDatabricks"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceAzureFileStorage",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceAzureFileStorage:LinkedServiceAzureFileStorage": "LinkedServiceAzureFileStorage"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceAzureFunction",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceAzureFunction:LinkedServiceAzureFunction": "LinkedServiceAzureFunction"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceAzureSqlDatabase",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceAzureSqlDatabase:LinkedServiceAzureSqlDatabase": "LinkedServiceAzureSqlDatabase"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceAzureTableStorage",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceAzureTableStorage:LinkedServiceAzureTableStorage": "LinkedServiceAzureTableStorage"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceCosmosDb",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceCosmosDb:LinkedServiceCosmosDb": "LinkedServiceCosmosDb"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceDataLakeStorageGen2",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceDataLakeStorageGen2:LinkedServiceDataLakeStorageGen2": "LinkedServiceDataLakeStorageGen2"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceKeyVault",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceKeyVault:LinkedServiceKeyVault": "LinkedServiceKeyVault"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceMysql",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceMysql:LinkedServiceMysql": "LinkedServiceMysql"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServicePostgresql",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServicePostgresql:LinkedServicePostgresql": "LinkedServicePostgresql"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceSftp",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceSftp:LinkedServiceSftp": "LinkedServiceSftp"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceSnowflake",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceSnowflake:LinkedServiceSnowflake": "LinkedServiceSnowflake"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceSqlServer",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceSqlServer:LinkedServiceSqlServer": "LinkedServiceSqlServer"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceSynapse",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceSynapse:LinkedServiceSynapse": "LinkedServiceSynapse"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceWeb",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceWeb:LinkedServiceWeb": "LinkedServiceWeb"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/pipeline",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/pipeline:Pipeline": "Pipeline"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/triggerSchedule",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/triggerSchedule:TriggerSchedule": "TriggerSchedule"
  }
 },
 {
  "pkg": "azure",
  "mod": "datalake/analyticsAccount",
  "fqn": "pulumi_azure.datalake",
  "classes": {
   "azure:datalake/analyticsAccount:AnalyticsAccount": "AnalyticsAccount"
  }
 },
 {
  "pkg": "azure",
  "mod": "datalake/analyticsFirewallRule",
  "fqn": "pulumi_azure.datalake",
  "classes": {
   "azure:datalake/analyticsFirewallRule:AnalyticsFirewallRule": "AnalyticsFirewallRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "datalake/store",
  "fqn": "pulumi_azure.datalake",
  "classes": {
   "azure:datalake/store:Store": "Store"
  }
 },
 {
  "pkg": "azure",
  "mod": "datalake/storeFile",
  "fqn": "pulumi_azure.datalake",
  "classes": {
   "azure:datalake/storeFile:StoreFile": "StoreFile"
  }
 },
 {
  "pkg": "azure",
  "mod": "datalake/storeFirewallRule",
  "fqn": "pulumi_azure.datalake",
  "classes": {
   "azure:datalake/storeFirewallRule:StoreFirewallRule": "StoreFirewallRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "datalake/storeVirtualNetworkRule",
  "fqn": "pulumi_azure.datalake",
  "classes": {
   "azure:datalake/storeVirtualNetworkRule:StoreVirtualNetworkRule": "StoreVirtualNetworkRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "datashare/account",
  "fqn": "pulumi_azure.datashare",
  "classes": {
   "azure:datashare/account:Account": "Account"
  }
 },
 {
  "pkg": "azure",
  "mod": "datashare/datasetBlobStorage",
  "fqn": "pulumi_azure.datashare",
  "classes": {
   "azure:datashare/datasetBlobStorage:DatasetBlobStorage": "DatasetBlobStorage"
  }
 },
 {
  "pkg": "azure",
  "mod": "datashare/datasetDataLakeGen1",
  "fqn": "pulumi_azure.datashare",
  "classes": {
   "azure:datashare/datasetDataLakeGen1:DatasetDataLakeGen1": "DatasetDataLakeGen1"
  }
 },
 {
  "pkg": "azure",
  "mod": "datashare/datasetDataLakeGen2",
  "fqn": "pulumi_azure.datashare",
  "classes": {
   "azure:datashare/datasetDataLakeGen2:DatasetDataLakeGen2": "DatasetDataLakeGen2"
  }
 },
 {
  "pkg": "azure",
  "mod": "datashare/datasetKustoCluster",
  "fqn": "pulumi_azure.datashare",
  "classes": {
   "azure:datashare/datasetKustoCluster:DatasetKustoCluster": "DatasetKustoCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "datashare/datasetKustoDatabase",
  "fqn": "pulumi_azure.datashare",
  "classes": {
   "azure:datashare/datasetKustoDatabase:DatasetKustoDatabase": "DatasetKustoDatabase"
  }
 },
 {
  "pkg": "azure",
  "mod": "datashare/share",
  "fqn": "pulumi_azure.datashare",
  "classes": {
   "azure:datashare/share:Share": "Share"
  }
 },
 {
  "pkg": "azure",
  "mod": "desktopvirtualization/applicationGroup",
  "fqn": "pulumi_azure.desktopvirtualization",
  "classes": {
   "azure:desktopvirtualization/applicationGroup:ApplicationGroup": "ApplicationGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "desktopvirtualization/hostPool",
  "fqn": "pulumi_azure.desktopvirtualization",
  "classes": {
   "azure:desktopvirtualization/hostPool:HostPool": "HostPool"
  }
 },
 {
  "pkg": "azure",
  "mod": "desktopvirtualization/workspace",
  "fqn": "pulumi_azure.desktopvirtualization",
  "classes": {
   "azure:desktopvirtualization/workspace:Workspace": "Workspace"
  }
 },
 {
  "pkg": "azure",
  "mod": "desktopvirtualization/workspaceApplicationGroupAssociation",
  "fqn": "pulumi_azure.desktopvirtualization",
  "classes": {
   "azure:desktopvirtualization/workspaceApplicationGroupAssociation:WorkspaceApplicationGroupAssociation": "WorkspaceApplicationGroupAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "devspace/controller",
  "fqn": "pulumi_azure.devspace",
  "classes": {
   "azure:devspace/controller:Controller": "Controller"
  }
 },
 {
  "pkg": "azure",
  "mod": "devtest/globalVMShutdownSchedule",
  "fqn": "pulumi_azure.devtest",
  "classes": {
   "azure:devtest/globalVMShutdownSchedule:GlobalVMShutdownSchedule": "GlobalVMShutdownSchedule"
  }
 },
 {
  "pkg": "azure",
  "mod": "devtest/lab",
  "fqn": "pulumi_azure.devtest",
  "classes": {
   "azure:devtest/lab:Lab": "Lab"
  }
 },
 {
  "pkg": "azure",
  "mod": "devtest/linuxVirtualMachine",
  "fqn": "pulumi_azure.devtest",
  "classes": {
   "azure:devtest/linuxVirtualMachine:LinuxVirtualMachine": "LinuxVirtualMachine"
  }
 },
 {
  "pkg": "azure",
  "mod": "devtest/policy",
  "fqn": "pulumi_azure.devtest",
  "classes": {
   "azure:devtest/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "azure",
  "mod": "devtest/schedule",
  "fqn": "pulumi_azure.devtest",
  "classes": {
   "azure:devtest/schedule:Schedule": "Schedule"
  }
 },
 {
  "pkg": "azure",
  "mod": "devtest/virtualNetwork",
  "fqn": "pulumi_azure.devtest",
  "classes": {
   "azure:devtest/virtualNetwork:VirtualNetwork": "VirtualNetwork"
  }
 },
 {
  "pkg": "azure",
  "mod": "devtest/windowsVirtualMachine",
  "fqn": "pulumi_azure.devtest",
  "classes": {
   "azure:devtest/windowsVirtualMachine:WindowsVirtualMachine": "WindowsVirtualMachine"
  }
 },
 {
  "pkg": "azure",
  "mod": "digitaltwins/endpointEventGrid",
  "fqn": "pulumi_azure.digitaltwins",
  "classes": {
   "azure:digitaltwins/endpointEventGrid:EndpointEventGrid": "EndpointEventGrid"
  }
 },
 {
  "pkg": "azure",
  "mod": "digitaltwins/endpointEventHub",
  "fqn": "pulumi_azure.digitaltwins",
  "classes": {
   "azure:digitaltwins/endpointEventHub:EndpointEventHub": "EndpointEventHub"
  }
 },
 {
  "pkg": "azure",
  "mod": "digitaltwins/endpointServicebus",
  "fqn": "pulumi_azure.digitaltwins",
  "classes": {
   "azure:digitaltwins/endpointServicebus:EndpointServicebus": "EndpointServicebus"
  }
 },
 {
  "pkg": "azure",
  "mod": "digitaltwins/instance",
  "fqn": "pulumi_azure.digitaltwins",
  "classes": {
   "azure:digitaltwins/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "azure",
  "mod": "dns/aRecord",
  "fqn": "pulumi_azure.dns",
  "classes": {
   "azure:dns/aRecord:ARecord": "ARecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "dns/aaaaRecord",
  "fqn": "pulumi_azure.dns",
  "classes": {
   "azure:dns/aaaaRecord:AaaaRecord": "AaaaRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "dns/cNameRecord",
  "fqn": "pulumi_azure.dns",
  "classes": {
   "azure:dns/cNameRecord:CNameRecord": "CNameRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "dns/caaRecord",
  "fqn": "pulumi_azure.dns",
  "classes": {
   "azure:dns/caaRecord:CaaRecord": "CaaRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "dns/mxRecord",
  "fqn": "pulumi_azure.dns",
  "classes": {
   "azure:dns/mxRecord:MxRecord": "MxRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "dns/nsRecord",
  "fqn": "pulumi_azure.dns",
  "classes": {
   "azure:dns/nsRecord:NsRecord": "NsRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "dns/ptrRecord",
  "fqn": "pulumi_azure.dns",
  "classes": {
   "azure:dns/ptrRecord:PtrRecord": "PtrRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "dns/srvRecord",
  "fqn": "pulumi_azure.dns",
  "classes": {
   "azure:dns/srvRecord:SrvRecord": "SrvRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "dns/txtRecord",
  "fqn": "pulumi_azure.dns",
  "classes": {
   "azure:dns/txtRecord:TxtRecord": "TxtRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "dns/zone",
  "fqn": "pulumi_azure.dns",
  "classes": {
   "azure:dns/zone:Zone": "Zone"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventgrid/domain",
  "fqn": "pulumi_azure.eventgrid",
  "classes": {
   "azure:eventgrid/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventgrid/domainTopic",
  "fqn": "pulumi_azure.eventgrid",
  "classes": {
   "azure:eventgrid/domainTopic:DomainTopic": "DomainTopic"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventgrid/eventSubscription",
  "fqn": "pulumi_azure.eventgrid",
  "classes": {
   "azure:eventgrid/eventSubscription:EventSubscription": "EventSubscription"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventgrid/getSystemTopic",
  "fqn": "pulumi_azure.eventgrid",
  "classes": {
   "azure:eventgrid/getSystemTopic:getSystemTopic": "GetSystemTopic"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventgrid/systemTopic",
  "fqn": "pulumi_azure.eventgrid",
  "classes": {
   "azure:eventgrid/systemTopic:SystemTopic": "SystemTopic"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventgrid/systemTopicEventSubscription",
  "fqn": "pulumi_azure.eventgrid",
  "classes": {
   "azure:eventgrid/systemTopicEventSubscription:SystemTopicEventSubscription": "SystemTopicEventSubscription"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventgrid/topic",
  "fqn": "pulumi_azure.eventgrid",
  "classes": {
   "azure:eventgrid/topic:Topic": "Topic"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/authorizationRule",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/authorizationRule:AuthorizationRule": "AuthorizationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/cluster",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/consumerGroup",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/consumerGroup:ConsumerGroup": "ConsumerGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/domain",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/eventGridTopic",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/eventGridTopic:EventGridTopic": "EventGridTopic"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/eventHub",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/eventHub:EventHub": "EventHub"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/eventHubAuthorizationRule",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/eventHubAuthorizationRule:EventHubAuthorizationRule": "EventHubAuthorizationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/eventHubConsumerGroup",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/eventHubConsumerGroup:EventHubConsumerGroup": "EventHubConsumerGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/eventHubNamespace",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/eventHubNamespace:EventHubNamespace": "EventHubNamespace"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/eventHubNamespaceAuthorizationRule",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/eventHubNamespaceAuthorizationRule:EventHubNamespaceAuthorizationRule": "EventHubNamespaceAuthorizationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/eventSubscription",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/eventSubscription:EventSubscription": "EventSubscription"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/eventhubNamespaceDisasterRecoveryConfig",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/eventhubNamespaceDisasterRecoveryConfig:EventhubNamespaceDisasterRecoveryConfig": "EventhubNamespaceDisasterRecoveryConfig"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/namespace",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/namespaceAuthorizationRule",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/namespaceAuthorizationRule:NamespaceAuthorizationRule": "NamespaceAuthorizationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/queue",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/queue:Queue": "Queue"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/queueAuthorizationRule",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/queueAuthorizationRule:QueueAuthorizationRule": "QueueAuthorizationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/subscription",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/subscription:Subscription": "Subscription"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/subscriptionRule",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/subscriptionRule:SubscriptionRule": "SubscriptionRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/topic",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/topic:Topic": "Topic"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/topicAuthorizationRule",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/topicAuthorizationRule:TopicAuthorizationRule": "TopicAuthorizationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "frontdoor/customHttpsConfiguration",
  "fqn": "pulumi_azure.frontdoor",
  "classes": {
   "azure:frontdoor/customHttpsConfiguration:CustomHttpsConfiguration": "CustomHttpsConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "frontdoor/firewallPolicy",
  "fqn": "pulumi_azure.frontdoor",
  "classes": {
   "azure:frontdoor/firewallPolicy:FirewallPolicy": "FirewallPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "frontdoor/frontdoor",
  "fqn": "pulumi_azure.frontdoor",
  "classes": {
   "azure:frontdoor/frontdoor:Frontdoor": "Frontdoor"
  }
 },
 {
  "pkg": "azure",
  "mod": "hdinsight/hBaseCluster",
  "fqn": "pulumi_azure.hdinsight",
  "classes": {
   "azure:hdinsight/hBaseCluster:HBaseCluster": "HBaseCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "hdinsight/hadoopCluster",
  "fqn": "pulumi_azure.hdinsight",
  "classes": {
   "azure:hdinsight/hadoopCluster:HadoopCluster": "HadoopCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "hdinsight/interactiveQueryCluster",
  "fqn": "pulumi_azure.hdinsight",
  "classes": {
   "azure:hdinsight/interactiveQueryCluster:InteractiveQueryCluster": "InteractiveQueryCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "hdinsight/kafkaCluster",
  "fqn": "pulumi_azure.hdinsight",
  "classes": {
   "azure:hdinsight/kafkaCluster:KafkaCluster": "KafkaCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "hdinsight/mLServicesCluster",
  "fqn": "pulumi_azure.hdinsight",
  "classes": {
   "azure:hdinsight/mLServicesCluster:MLServicesCluster": "MLServicesCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "hdinsight/rServerCluster",
  "fqn": "pulumi_azure.hdinsight",
  "classes": {
   "azure:hdinsight/rServerCluster:RServerCluster": "RServerCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "hdinsight/sparkCluster",
  "fqn": "pulumi_azure.hdinsight",
  "classes": {
   "azure:hdinsight/sparkCluster:SparkCluster": "SparkCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "hdinsight/stormCluster",
  "fqn": "pulumi_azure.hdinsight",
  "classes": {
   "azure:hdinsight/stormCluster:StormCluster": "StormCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "healthcare/service",
  "fqn": "pulumi_azure.healthcare",
  "classes": {
   "azure:healthcare/service:Service": "Service"
  }
 },
 {
  "pkg": "azure",
  "mod": "hpc/cache",
  "fqn": "pulumi_azure.hpc",
  "classes": {
   "azure:hpc/cache:Cache": "Cache"
  }
 },
 {
  "pkg": "azure",
  "mod": "hpc/cacheAccessPolicy",
  "fqn": "pulumi_azure.hpc",
  "classes": {
   "azure:hpc/cacheAccessPolicy:CacheAccessPolicy": "CacheAccessPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "hpc/cacheBlobTarget",
  "fqn": "pulumi_azure.hpc",
  "classes": {
   "azure:hpc/cacheBlobTarget:CacheBlobTarget": "CacheBlobTarget"
  }
 },
 {
  "pkg": "azure",
  "mod": "hpc/cacheNfsTarget",
  "fqn": "pulumi_azure.hpc",
  "classes": {
   "azure:hpc/cacheNfsTarget:CacheNfsTarget": "CacheNfsTarget"
  }
 },
 {
  "pkg": "azure",
  "mod": "hsm/module",
  "fqn": "pulumi_azure.hsm",
  "classes": {
   "azure:hsm/module:Module": "Module"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/consumerGroup",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/consumerGroup:ConsumerGroup": "ConsumerGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/dpsSharedAccessPolicy",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/dpsSharedAccessPolicy:DpsSharedAccessPolicy": "DpsSharedAccessPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/endpointEventhub",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/endpointEventhub:EndpointEventhub": "EndpointEventhub"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/endpointServicebusQueue",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/endpointServicebusQueue:EndpointServicebusQueue": "EndpointServicebusQueue"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/endpointServicebusTopic",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/endpointServicebusTopic:EndpointServicebusTopic": "EndpointServicebusTopic"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/endpointStorageContainer",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/endpointStorageContainer:EndpointStorageContainer": "EndpointStorageContainer"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/enrichment",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/enrichment:Enrichment": "Enrichment"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/fallbackRoute",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/fallbackRoute:FallbackRoute": "FallbackRoute"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/ioTHub",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/ioTHub:IoTHub": "IoTHub"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/iotHubCertificate",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/iotHubCertificate:IotHubCertificate": "IotHubCertificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/iotHubDps",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/iotHubDps:IotHubDps": "IotHubDps"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/route",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/route:Route": "Route"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/securityDeviceGroup",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/securityDeviceGroup:SecurityDeviceGroup": "SecurityDeviceGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/securitySolution",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/securitySolution:SecuritySolution": "SecuritySolution"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/sharedAccessPolicy",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/sharedAccessPolicy:SharedAccessPolicy": "SharedAccessPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/timeSeriesInsightsAccessPolicy",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/timeSeriesInsightsAccessPolicy:TimeSeriesInsightsAccessPolicy": "TimeSeriesInsightsAccessPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/timeSeriesInsightsEventSourceIothub",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/timeSeriesInsightsEventSourceIothub:TimeSeriesInsightsEventSourceIothub": "TimeSeriesInsightsEventSourceIothub"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/timeSeriesInsightsGen2Environment",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/timeSeriesInsightsGen2Environment:TimeSeriesInsightsGen2Environment": "TimeSeriesInsightsGen2Environment"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/timeSeriesInsightsReferenceDataSet",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/timeSeriesInsightsReferenceDataSet:TimeSeriesInsightsReferenceDataSet": "TimeSeriesInsightsReferenceDataSet"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/timeSeriesInsightsStandardEnvironment",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/timeSeriesInsightsStandardEnvironment:TimeSeriesInsightsStandardEnvironment": "TimeSeriesInsightsStandardEnvironment"
  }
 },
 {
  "pkg": "azure",
  "mod": "iotcentral/application",
  "fqn": "pulumi_azure.iotcentral",
  "classes": {
   "azure:iotcentral/application:Application": "Application"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/accessPolicy",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/accessPolicy:AccessPolicy": "AccessPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/certifiate",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/certifiate:Certifiate": "Certifiate"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/certificate",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/certificateIssuer",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/certificateIssuer:CertificateIssuer": "CertificateIssuer"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/key",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/key:Key": "Key"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/keyVault",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/keyVault:KeyVault": "KeyVault"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/managedHardwareSecurityModule",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/managedHardwareSecurityModule:ManagedHardwareSecurityModule": "ManagedHardwareSecurityModule"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/secret",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/secret:Secret": "Secret"
  }
 },
 {
  "pkg": "azure",
  "mod": "kusto/attachedDatabaseConfiguration",
  "fqn": "pulumi_azure.kusto",
  "classes": {
   "azure:kusto/attachedDatabaseConfiguration:AttachedDatabaseConfiguration": "AttachedDatabaseConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "kusto/cluster",
  "fqn": "pulumi_azure.kusto",
  "classes": {
   "azure:kusto/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "kusto/clusterCustomerManagedKey",
  "fqn": "pulumi_azure.kusto",
  "classes": {
   "azure:kusto/clusterCustomerManagedKey:ClusterCustomerManagedKey": "ClusterCustomerManagedKey"
  }
 },
 {
  "pkg": "azure",
  "mod": "kusto/clusterPrincipalAssignment",
  "fqn": "pulumi_azure.kusto",
  "classes": {
   "azure:kusto/clusterPrincipalAssignment:ClusterPrincipalAssignment": "ClusterPrincipalAssignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "kusto/database",
  "fqn": "pulumi_azure.kusto",
  "classes": {
   "azure:kusto/database:Database": "Database"
  }
 },
 {
  "pkg": "azure",
  "mod": "kusto/databasePrincipal",
  "fqn": "pulumi_azure.kusto",
  "classes": {
   "azure:kusto/databasePrincipal:DatabasePrincipal": "DatabasePrincipal"
  }
 },
 {
  "pkg": "azure",
  "mod": "kusto/databasePrincipalAssignment",
  "fqn": "pulumi_azure.kusto",
  "classes": {
   "azure:kusto/databasePrincipalAssignment:DatabasePrincipalAssignment": "DatabasePrincipalAssignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "kusto/eventGridDataConnection",
  "fqn": "pulumi_azure.kusto",
  "classes": {
   "azure:kusto/eventGridDataConnection:EventGridDataConnection": "EventGridDataConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "kusto/eventhubDataConnection",
  "fqn": "pulumi_azure.kusto",
  "classes": {
   "azure:kusto/eventhubDataConnection:EventhubDataConnection": "EventhubDataConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "kusto/iotHubDataConnection",
  "fqn": "pulumi_azure.kusto",
  "classes": {
   "azure:kusto/iotHubDataConnection:IotHubDataConnection": "IotHubDataConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "lb/backendAddressPool",
  "fqn": "pulumi_azure.lb",
  "classes": {
   "azure:lb/backendAddressPool:BackendAddressPool": "BackendAddressPool"
  }
 },
 {
  "pkg": "azure",
  "mod": "lb/backendAddressPoolAddress",
  "fqn": "pulumi_azure.lb",
  "classes": {
   "azure:lb/backendAddressPoolAddress:BackendAddressPoolAddress": "BackendAddressPoolAddress"
  }
 },
 {
  "pkg": "azure",
  "mod": "lb/loadBalancer",
  "fqn": "pulumi_azure.lb",
  "classes": {
   "azure:lb/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "azure",
  "mod": "lb/natPool",
  "fqn": "pulumi_azure.lb",
  "classes": {
   "azure:lb/natPool:NatPool": "NatPool"
  }
 },
 {
  "pkg": "azure",
  "mod": "lb/natRule",
  "fqn": "pulumi_azure.lb",
  "classes": {
   "azure:lb/natRule:NatRule": "NatRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "lb/outboundRule",
  "fqn": "pulumi_azure.lb",
  "classes": {
   "azure:lb/outboundRule:OutboundRule": "OutboundRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "lb/probe",
  "fqn": "pulumi_azure.lb",
  "classes": {
   "azure:lb/probe:Probe": "Probe"
  }
 },
 {
  "pkg": "azure",
  "mod": "lb/rule",
  "fqn": "pulumi_azure.lb",
  "classes": {
   "azure:lb/rule:Rule": "Rule"
  }
 },
 {
  "pkg": "azure",
  "mod": "lighthouse/assignment",
  "fqn": "pulumi_azure.lighthouse",
  "classes": {
   "azure:lighthouse/assignment:Assignment": "Assignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "lighthouse/definition",
  "fqn": "pulumi_azure.lighthouse",
  "classes": {
   "azure:lighthouse/definition:Definition": "Definition"
  }
 },
 {
  "pkg": "azure",
  "mod": "loganalytics/cluster",
  "fqn": "pulumi_azure.loganalytics",
  "classes": {
   "azure:loganalytics/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "loganalytics/clusterCustomerManagedKey",
  "fqn": "pulumi_azure.loganalytics",
  "classes": {
   "azure:loganalytics/clusterCustomerManagedKey:ClusterCustomerManagedKey": "ClusterCustomerManagedKey"
  }
 },
 {
  "pkg": "azure",
  "mod": "loganalytics/dataExportRule",
  "fqn": "pulumi_azure.loganalytics",
  "classes": {
   "azure:loganalytics/dataExportRule:DataExportRule": "DataExportRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "loganalytics/dataSourceWindowsEvent",
  "fqn": "pulumi_azure.loganalytics",
  "classes": {
   "azure:loganalytics/dataSourceWindowsEvent:DataSourceWindowsEvent": "DataSourceWindowsEvent"
  }
 },
 {
  "pkg": "azure",
  "mod": "loganalytics/dataSourceWindowsPerformanceCounter",
  "fqn": "pulumi_azure.loganalytics",
  "classes": {
   "azure:loganalytics/dataSourceWindowsPerformanceCounter:DataSourceWindowsPerformanceCounter": "DataSourceWindowsPerformanceCounter"
  }
 },
 {
  "pkg": "azure",
  "mod": "loganalytics/linkedService",
  "fqn": "pulumi_azure.loganalytics",
  "classes": {
   "azure:loganalytics/linkedService:LinkedService": "LinkedService"
  }
 },
 {
  "pkg": "azure",
  "mod": "loganalytics/linkedStorageAccount",
  "fqn": "pulumi_azure.loganalytics",
  "classes": {
   "azure:loganalytics/linkedStorageAccount:LinkedStorageAccount": "LinkedStorageAccount"
  }
 },
 {
  "pkg": "azure",
  "mod": "loganalytics/savedSearch",
  "fqn": "pulumi_azure.loganalytics",
  "classes": {
   "azure:loganalytics/savedSearch:SavedSearch": "SavedSearch"
  }
 },
 {
  "pkg": "azure",
  "mod": "loganalytics/storageInsights",
  "fqn": "pulumi_azure.loganalytics",
  "classes": {
   "azure:loganalytics/storageInsights:StorageInsights": "StorageInsights"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/actionCustom",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/actionCustom:ActionCustom": "ActionCustom"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/actionHttp",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/actionHttp:ActionHttp": "ActionHttp"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/integrationAccount",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/integrationAccount:IntegrationAccount": "IntegrationAccount"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/interationServiceEnvironment",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/interationServiceEnvironment:InterationServiceEnvironment": "InterationServiceEnvironment"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/triggerCustom",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/triggerCustom:TriggerCustom": "TriggerCustom"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/triggerHttpRequest",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/triggerHttpRequest:TriggerHttpRequest": "TriggerHttpRequest"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/triggerRecurrence",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/triggerRecurrence:TriggerRecurrence": "TriggerRecurrence"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/workflow",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/workflow:Workflow": "Workflow"
  }
 },
 {
  "pkg": "azure",
  "mod": "machinelearning/inferenceCluster",
  "fqn": "pulumi_azure.machinelearning",
  "classes": {
   "azure:machinelearning/inferenceCluster:InferenceCluster": "InferenceCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "machinelearning/workspace",
  "fqn": "pulumi_azure.machinelearning",
  "classes": {
   "azure:machinelearning/workspace:Workspace": "Workspace"
  }
 },
 {
  "pkg": "azure",
  "mod": "maintenance/assignmentDedicatedHost",
  "fqn": "pulumi_azure.maintenance",
  "classes": {
   "azure:maintenance/assignmentDedicatedHost:AssignmentDedicatedHost": "AssignmentDedicatedHost"
  }
 },
 {
  "pkg": "azure",
  "mod": "maintenance/assignmentVirtualMachine",
  "fqn": "pulumi_azure.maintenance",
  "classes": {
   "azure:maintenance/assignmentVirtualMachine:AssignmentVirtualMachine": "AssignmentVirtualMachine"
  }
 },
 {
  "pkg": "azure",
  "mod": "maintenance/configuration",
  "fqn": "pulumi_azure.maintenance",
  "classes": {
   "azure:maintenance/configuration:Configuration": "Configuration"
  }
 },
 {
  "pkg": "azure",
  "mod": "managedapplication/application",
  "fqn": "pulumi_azure.managedapplication",
  "classes": {
   "azure:managedapplication/application:Application": "Application"
  }
 },
 {
  "pkg": "azure",
  "mod": "managedapplication/definition",
  "fqn": "pulumi_azure.managedapplication",
  "classes": {
   "azure:managedapplication/definition:Definition": "Definition"
  }
 },
 {
  "pkg": "azure",
  "mod": "management/group",
  "fqn": "pulumi_azure.management",
  "classes": {
   "azure:management/group:Group": "Group"
  }
 },
 {
  "pkg": "azure",
  "mod": "management/groupSubscriptionAssociation",
  "fqn": "pulumi_azure.management",
  "classes": {
   "azure:management/groupSubscriptionAssociation:GroupSubscriptionAssociation": "GroupSubscriptionAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "management/groupTemplateDeployment",
  "fqn": "pulumi_azure.management",
  "classes": {
   "azure:management/groupTemplateDeployment:GroupTemplateDeployment": "GroupTemplateDeployment"
  }
 },
 {
  "pkg": "azure",
  "mod": "management/lock",
  "fqn": "pulumi_azure.management",
  "classes": {
   "azure:management/lock:Lock": "Lock"
  }
 },
 {
  "pkg": "azure",
  "mod": "managementgroups/managementGroup",
  "fqn": "pulumi_azure.managementgroups",
  "classes": {
   "azure:managementgroups/managementGroup:ManagementGroup": "ManagementGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "managementresource/manangementLock",
  "fqn": "pulumi_azure.managementresource",
  "classes": {
   "azure:managementresource/manangementLock:ManangementLock": "ManangementLock"
  }
 },
 {
  "pkg": "azure",
  "mod": "maps/account",
  "fqn": "pulumi_azure.maps",
  "classes": {
   "azure:maps/account:Account": "Account"
  }
 },
 {
  "pkg": "azure",
  "mod": "mariadb/configuration",
  "fqn": "pulumi_azure.mariadb",
  "classes": {
   "azure:mariadb/configuration:Configuration": "Configuration"
  }
 },
 {
  "pkg": "azure",
  "mod": "mariadb/database",
  "fqn": "pulumi_azure.mariadb",
  "classes": {
   "azure:mariadb/database:Database": "Database"
  }
 },
 {
  "pkg": "azure",
  "mod": "mariadb/firewallRule",
  "fqn": "pulumi_azure.mariadb",
  "classes": {
   "azure:mariadb/firewallRule:FirewallRule": "FirewallRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "mariadb/server",
  "fqn": "pulumi_azure.mariadb",
  "classes": {
   "azure:mariadb/server:Server": "Server"
  }
 },
 {
  "pkg": "azure",
  "mod": "mariadb/virtualNetworkRule",
  "fqn": "pulumi_azure.mariadb",
  "classes": {
   "azure:mariadb/virtualNetworkRule:VirtualNetworkRule": "VirtualNetworkRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "marketplace/agreement",
  "fqn": "pulumi_azure.marketplace",
  "classes": {
   "azure:marketplace/agreement:Agreement": "Agreement"
  }
 },
 {
  "pkg": "azure",
  "mod": "media/asset",
  "fqn": "pulumi_azure.media",
  "classes": {
   "azure:media/asset:Asset": "Asset"
  }
 },
 {
  "pkg": "azure",
  "mod": "media/assetFilter",
  "fqn": "pulumi_azure.media",
  "classes": {
   "azure:media/assetFilter:AssetFilter": "AssetFilter"
  }
 },
 {
  "pkg": "azure",
  "mod": "media/contentKeyPolicy",
  "fqn": "pulumi_azure.media",
  "classes": {
   "azure:media/contentKeyPolicy:ContentKeyPolicy": "ContentKeyPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "media/job",
  "fqn": "pulumi_azure.media",
  "classes": {
   "azure:media/job:Job": "Job"
  }
 },
 {
  "pkg": "azure",
  "mod": "media/liveEvent",
  "fqn": "pulumi_azure.media",
  "classes": {
   "azure:media/liveEvent:LiveEvent": "LiveEvent"
  }
 },
 {
  "pkg": "azure",
  "mod": "media/liveEventOutput",
  "fqn": "pulumi_azure.media",
  "classes": {
   "azure:media/liveEventOutput:LiveEventOutput": "LiveEventOutput"
  }
 },
 {
  "pkg": "azure",
  "mod": "media/serviceAccount",
  "fqn": "pulumi_azure.media",
  "classes": {
   "azure:media/serviceAccount:ServiceAccount": "ServiceAccount"
  }
 },
 {
  "pkg": "azure",
  "mod": "media/streamingEndpoint",
  "fqn": "pulumi_azure.media",
  "classes": {
   "azure:media/streamingEndpoint:StreamingEndpoint": "StreamingEndpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "media/streamingLocator",
  "fqn": "pulumi_azure.media",
  "classes": {
   "azure:media/streamingLocator:StreamingLocator": "StreamingLocator"
  }
 },
 {
  "pkg": "azure",
  "mod": "media/streamingPolicy",
  "fqn": "pulumi_azure.media",
  "classes": {
   "azure:media/streamingPolicy:StreamingPolicy": "StreamingPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "media/transform",
  "fqn": "pulumi_azure.media",
  "classes": {
   "azure:media/transform:Transform": "Transform"
  }
 },
 {
  "pkg": "azure",
  "mod": "mediaservices/account",
  "fqn": "pulumi_azure.mediaservices",
  "classes": {
   "azure:mediaservices/account:Account": "Account"
  }
 },
 {
  "pkg": "azure",
  "mod": "mixedreality/spatialAnchorsAccount",
  "fqn": "pulumi_azure.mixedreality",
  "classes": {
   "azure:mixedreality/spatialAnchorsAccount:SpatialAnchorsAccount": "SpatialAnchorsAccount"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/aadDiagnosticSetting",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/aadDiagnosticSetting:AadDiagnosticSetting": "AadDiagnosticSetting"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/actionGroup",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/actionGroup:ActionGroup": "ActionGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/actionRuleActionGroup",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/actionRuleActionGroup:ActionRuleActionGroup": "ActionRuleActionGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/actionRuleSuppression",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/actionRuleSuppression:ActionRuleSuppression": "ActionRuleSuppression"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/activityLogAlert",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/activityLogAlert:ActivityLogAlert": "ActivityLogAlert"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/autoscaleSetting",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/autoscaleSetting:AutoscaleSetting": "AutoscaleSetting"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/diagnosticSetting",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/diagnosticSetting:DiagnosticSetting": "DiagnosticSetting"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/logProfile",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/logProfile:LogProfile": "LogProfile"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/metricAlert",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/metricAlert:MetricAlert": "MetricAlert"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/scheduledQueryRulesAlert",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/scheduledQueryRulesAlert:ScheduledQueryRulesAlert": "ScheduledQueryRulesAlert"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/scheduledQueryRulesLog",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/scheduledQueryRulesLog:ScheduledQueryRulesLog": "ScheduledQueryRulesLog"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/smartDetectorAlertRule",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/smartDetectorAlertRule:SmartDetectorAlertRule": "SmartDetectorAlertRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "msi/userAssignedIdentity",
  "fqn": "pulumi_azure.msi",
  "classes": {
   "azure:msi/userAssignedIdentity:UserAssignedIdentity": "UserAssignedIdentity"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/database",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/database:Database": "Database"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/databaseExtendedAuditingPolicy",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/databaseExtendedAuditingPolicy:DatabaseExtendedAuditingPolicy": "DatabaseExtendedAuditingPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/databaseVulnerabilityAssessmentRuleBaseline",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/databaseVulnerabilityAssessmentRuleBaseline:DatabaseVulnerabilityAssessmentRuleBaseline": "DatabaseVulnerabilityAssessmentRuleBaseline"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/elasticPool",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/elasticPool:ElasticPool": "ElasticPool"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/firewallRule",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/firewallRule:FirewallRule": "FirewallRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/jobAgent",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/jobAgent:JobAgent": "JobAgent"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/jobCredential",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/jobCredential:JobCredential": "JobCredential"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/server",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/server:Server": "Server"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/serverExtendedAuditingPolicy",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/serverExtendedAuditingPolicy:ServerExtendedAuditingPolicy": "ServerExtendedAuditingPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/serverSecurityAlertPolicy",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/serverSecurityAlertPolicy:ServerSecurityAlertPolicy": "ServerSecurityAlertPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/serverTransparentDataEncryption",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/serverTransparentDataEncryption:ServerTransparentDataEncryption": "ServerTransparentDataEncryption"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/serverVulnerabilityAssessment",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/serverVulnerabilityAssessment:ServerVulnerabilityAssessment": "ServerVulnerabilityAssessment"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/virtualMachine",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/virtualMachine:VirtualMachine": "VirtualMachine"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/virtualNetworkRule",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/virtualNetworkRule:VirtualNetworkRule": "VirtualNetworkRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "mysql/activeDirectoryAdministrator",
  "fqn": "pulumi_azure.mysql",
  "classes": {
   "azure:mysql/activeDirectoryAdministrator:ActiveDirectoryAdministrator": "ActiveDirectoryAdministrator"
  }
 },
 {
  "pkg": "azure",
  "mod": "mysql/configuration",
  "fqn": "pulumi_azure.mysql",
  "classes": {
   "azure:mysql/configuration:Configuration": "Configuration"
  }
 },
 {
  "pkg": "azure",
  "mod": "mysql/database",
  "fqn": "pulumi_azure.mysql",
  "classes": {
   "azure:mysql/database:Database": "Database"
  }
 },
 {
  "pkg": "azure",
  "mod": "mysql/firewallRule",
  "fqn": "pulumi_azure.mysql",
  "classes": {
   "azure:mysql/firewallRule:FirewallRule": "FirewallRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "mysql/server",
  "fqn": "pulumi_azure.mysql",
  "classes": {
   "azure:mysql/server:Server": "Server"
  }
 },
 {
  "pkg": "azure",
  "mod": "mysql/serverKey",
  "fqn": "pulumi_azure.mysql",
  "classes": {
   "azure:mysql/serverKey:ServerKey": "ServerKey"
  }
 },
 {
  "pkg": "azure",
  "mod": "mysql/virtualNetworkRule",
  "fqn": "pulumi_azure.mysql",
  "classes": {
   "azure:mysql/virtualNetworkRule:VirtualNetworkRule": "VirtualNetworkRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "netapp/account",
  "fqn": "pulumi_azure.netapp",
  "classes": {
   "azure:netapp/account:Account": "Account"
  }
 },
 {
  "pkg": "azure",
  "mod": "netapp/pool",
  "fqn": "pulumi_azure.netapp",
  "classes": {
   "azure:netapp/pool:Pool": "Pool"
  }
 },
 {
  "pkg": "azure",
  "mod": "netapp/snapshot",
  "fqn": "pulumi_azure.netapp",
  "classes": {
   "azure:netapp/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "azure",
  "mod": "netapp/volume",
  "fqn": "pulumi_azure.netapp",
  "classes": {
   "azure:netapp/volume:Volume": "Volume"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/applicationGateway",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/applicationGateway:ApplicationGateway": "ApplicationGateway"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/applicationSecurityGroup",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/applicationSecurityGroup:ApplicationSecurityGroup": "ApplicationSecurityGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/bgpConnection",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/bgpConnection:BgpConnection": "BgpConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/ddosProtectionPlan",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/ddosProtectionPlan:DdosProtectionPlan": "DdosProtectionPlan"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/expressRouteCircuit",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/expressRouteCircuit:ExpressRouteCircuit": "ExpressRouteCircuit"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/expressRouteCircuitAuthorization",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/expressRouteCircuitAuthorization:ExpressRouteCircuitAuthorization": "ExpressRouteCircuitAuthorization"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/expressRouteCircuitPeering",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/expressRouteCircuitPeering:ExpressRouteCircuitPeering": "ExpressRouteCircuitPeering"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/expressRouteGateway",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/expressRouteGateway:ExpressRouteGateway": "ExpressRouteGateway"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/expressRoutePort",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/expressRoutePort:ExpressRoutePort": "ExpressRoutePort"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/firewall",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/firewall:Firewall": "Firewall"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/firewallApplicationRuleCollection",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/firewallApplicationRuleCollection:FirewallApplicationRuleCollection": "FirewallApplicationRuleCollection"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/firewallNatRuleCollection",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/firewallNatRuleCollection:FirewallNatRuleCollection": "FirewallNatRuleCollection"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/firewallNetworkRuleCollection",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/firewallNetworkRuleCollection:FirewallNetworkRuleCollection": "FirewallNetworkRuleCollection"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/firewallPolicy",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/firewallPolicy:FirewallPolicy": "FirewallPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/firewallPolicyRuleCollectionGroup",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/firewallPolicyRuleCollectionGroup:FirewallPolicyRuleCollectionGroup": "FirewallPolicyRuleCollectionGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/iPGroup",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/iPGroup:IPGroup": "IPGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/localNetworkGateway",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/localNetworkGateway:LocalNetworkGateway": "LocalNetworkGateway"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/natGateway",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/natGateway:NatGateway": "NatGateway"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/natGatewayPublicIpAssociation",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/natGatewayPublicIpAssociation:NatGatewayPublicIpAssociation": "NatGatewayPublicIpAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkConnectionMonitor",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkConnectionMonitor:NetworkConnectionMonitor": "NetworkConnectionMonitor"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkInterface",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkInterface:NetworkInterface": "NetworkInterface"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkInterfaceApplicationGatewayBackendAddressPoolAssociation",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkInterfaceApplicationGatewayBackendAddressPoolAssociation:NetworkInterfaceApplicationGatewayBackendAddressPoolAssociation": "NetworkInterfaceApplicationGatewayBackendAddressPoolAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkInterfaceApplicationSecurityGroupAssociation",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkInterfaceApplicationSecurityGroupAssociation:NetworkInterfaceApplicationSecurityGroupAssociation": "NetworkInterfaceApplicationSecurityGroupAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkInterfaceBackendAddressPoolAssociation",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkInterfaceBackendAddressPoolAssociation:NetworkInterfaceBackendAddressPoolAssociation": "NetworkInterfaceBackendAddressPoolAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkInterfaceNatRuleAssociation",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkInterfaceNatRuleAssociation:NetworkInterfaceNatRuleAssociation": "NetworkInterfaceNatRuleAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkInterfaceSecurityGroupAssociation",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkInterfaceSecurityGroupAssociation:NetworkInterfaceSecurityGroupAssociation": "NetworkInterfaceSecurityGroupAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkPacketCapture",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkPacketCapture:NetworkPacketCapture": "NetworkPacketCapture"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkSecurityGroup",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkSecurityGroup:NetworkSecurityGroup": "NetworkSecurityGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkSecurityRule",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkSecurityRule:NetworkSecurityRule": "NetworkSecurityRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkWatcher",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkWatcher:NetworkWatcher": "NetworkWatcher"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkWatcherFlowLog",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkWatcherFlowLog:NetworkWatcherFlowLog": "NetworkWatcherFlowLog"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/packetCapture",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/packetCapture:PacketCapture": "PacketCapture"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/pointToPointVpnGateway",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/pointToPointVpnGateway:PointToPointVpnGateway": "PointToPointVpnGateway"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/profile",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/profile:Profile": "Profile"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/publicIp",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/publicIp:PublicIp": "PublicIp"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/publicIpPrefix",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/publicIpPrefix:PublicIpPrefix": "PublicIpPrefix"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/route",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/route:Route": "Route"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/routeFilter",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/routeFilter:RouteFilter": "RouteFilter"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/routeTable",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/routeTable:RouteTable": "RouteTable"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/securityPartnerProvider",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/securityPartnerProvider:SecurityPartnerProvider": "SecurityPartnerProvider"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/subnet",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/subnet:Subnet": "Subnet"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/subnetNatGatewayAssociation",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/subnetNatGatewayAssociation:SubnetNatGatewayAssociation": "SubnetNatGatewayAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/subnetNetworkSecurityGroupAssociation",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/subnetNetworkSecurityGroupAssociation:SubnetNetworkSecurityGroupAssociation": "SubnetNetworkSecurityGroupAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/subnetRouteTableAssociation",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/subnetRouteTableAssociation:SubnetRouteTableAssociation": "SubnetRouteTableAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/subnetServiceEndpointStoragePolicy",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/subnetServiceEndpointStoragePolicy:SubnetServiceEndpointStoragePolicy": "SubnetServiceEndpointStoragePolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/trafficManagerEndpoint",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/trafficManagerEndpoint:TrafficManagerEndpoint": "TrafficManagerEndpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/trafficManagerProfile",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/trafficManagerProfile:TrafficManagerProfile": "TrafficManagerProfile"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/virtualHub",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/virtualHub:VirtualHub": "VirtualHub"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/virtualHubConnection",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/virtualHubConnection:VirtualHubConnection": "VirtualHubConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/virtualHubIp",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/virtualHubIp:VirtualHubIp": "VirtualHubIp"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/virtualHubRouteTable",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/virtualHubRouteTable:VirtualHubRouteTable": "VirtualHubRouteTable"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/virtualNetwork",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/virtualNetwork:VirtualNetwork": "VirtualNetwork"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/virtualNetworkGateway",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/virtualNetworkGateway:VirtualNetworkGateway": "VirtualNetworkGateway"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/virtualNetworkGatewayConnection",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/virtualNetworkGatewayConnection:VirtualNetworkGatewayConnection": "VirtualNetworkGatewayConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/virtualNetworkPeering",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/virtualNetworkPeering:VirtualNetworkPeering": "VirtualNetworkPeering"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/virtualWan",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/virtualWan:VirtualWan": "VirtualWan"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/vpnGateway",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/vpnGateway:VpnGateway": "VpnGateway"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/vpnGatewayConnection",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/vpnGatewayConnection:VpnGatewayConnection": "VpnGatewayConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/vpnServerConfiguration",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/vpnServerConfiguration:VpnServerConfiguration": "VpnServerConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/vpnSite",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/vpnSite:VpnSite": "VpnSite"
  }
 },
 {
  "pkg": "azure",
  "mod": "notificationhub/authorizationRule",
  "fqn": "pulumi_azure.notificationhub",
  "classes": {
   "azure:notificationhub/authorizationRule:AuthorizationRule": "AuthorizationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "notificationhub/hub",
  "fqn": "pulumi_azure.notificationhub",
  "classes": {
   "azure:notificationhub/hub:Hub": "Hub"
  }
 },
 {
  "pkg": "azure",
  "mod": "notificationhub/namespace",
  "fqn": "pulumi_azure.notificationhub",
  "classes": {
   "azure:notificationhub/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "azure",
  "mod": "operationalinsights/analyticsSolution",
  "fqn": "pulumi_azure.operationalinsights",
  "classes": {
   "azure:operationalinsights/analyticsSolution:AnalyticsSolution": "AnalyticsSolution"
  }
 },
 {
  "pkg": "azure",
  "mod": "operationalinsights/analyticsWorkspace",
  "fqn": "pulumi_azure.operationalinsights",
  "classes": {
   "azure:operationalinsights/analyticsWorkspace:AnalyticsWorkspace": "AnalyticsWorkspace"
  }
 },
 {
  "pkg": "azure",
  "mod": "policy/assignment",
  "fqn": "pulumi_azure.policy",
  "classes": {
   "azure:policy/assignment:Assignment": "Assignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "policy/definition",
  "fqn": "pulumi_azure.policy",
  "classes": {
   "azure:policy/definition:Definition": "Definition"
  }
 },
 {
  "pkg": "azure",
  "mod": "policy/policySetDefinition",
  "fqn": "pulumi_azure.policy",
  "classes": {
   "azure:policy/policySetDefinition:PolicySetDefinition": "PolicySetDefinition"
  }
 },
 {
  "pkg": "azure",
  "mod": "policy/remediation",
  "fqn": "pulumi_azure.policy",
  "classes": {
   "azure:policy/remediation:Remediation": "Remediation"
  }
 },
 {
  "pkg": "azure",
  "mod": "postgresql/activeDirectoryAdministrator",
  "fqn": "pulumi_azure.postgresql",
  "classes": {
   "azure:postgresql/activeDirectoryAdministrator:ActiveDirectoryAdministrator": "ActiveDirectoryAdministrator"
  }
 },
 {
  "pkg": "azure",
  "mod": "postgresql/configuration",
  "fqn": "pulumi_azure.postgresql",
  "classes": {
   "azure:postgresql/configuration:Configuration": "Configuration"
  }
 },
 {
  "pkg": "azure",
  "mod": "postgresql/database",
  "fqn": "pulumi_azure.postgresql",
  "classes": {
   "azure:postgresql/database:Database": "Database"
  }
 },
 {
  "pkg": "azure",
  "mod": "postgresql/firewallRule",
  "fqn": "pulumi_azure.postgresql",
  "classes": {
   "azure:postgresql/firewallRule:FirewallRule": "FirewallRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "postgresql/flexibleServer",
  "fqn": "pulumi_azure.postgresql",
  "classes": {
   "azure:postgresql/flexibleServer:FlexibleServer": "FlexibleServer"
  }
 },
 {
  "pkg": "azure",
  "mod": "postgresql/server",
  "fqn": "pulumi_azure.postgresql",
  "classes": {
   "azure:postgresql/server:Server": "Server"
  }
 },
 {
  "pkg": "azure",
  "mod": "postgresql/serverKey",
  "fqn": "pulumi_azure.postgresql",
  "classes": {
   "azure:postgresql/serverKey:ServerKey": "ServerKey"
  }
 },
 {
  "pkg": "azure",
  "mod": "postgresql/virtualNetworkRule",
  "fqn": "pulumi_azure.postgresql",
  "classes": {
   "azure:postgresql/virtualNetworkRule:VirtualNetworkRule": "VirtualNetworkRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "powerbi/embedded",
  "fqn": "pulumi_azure.powerbi",
  "classes": {
   "azure:powerbi/embedded:Embedded": "Embedded"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/aAAARecord",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/aAAARecord:AAAARecord": "AAAARecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/aRecord",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/aRecord:ARecord": "ARecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/cnameRecord",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/cnameRecord:CnameRecord": "CnameRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/linkService",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/linkService:LinkService": "LinkService"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/mxRecord",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/mxRecord:MxRecord": "MxRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/pTRRecord",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/pTRRecord:PTRRecord": "PTRRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/sRVRecord",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/sRVRecord:SRVRecord": "SRVRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/txtRecord",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/txtRecord:TxtRecord": "TxtRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/zone",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/zone:Zone": "Zone"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/zoneVirtualNetworkLink",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/zoneVirtualNetworkLink:ZoneVirtualNetworkLink": "ZoneVirtualNetworkLink"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatelink/endpoint",
  "fqn": "pulumi_azure.privatelink",
  "classes": {
   "azure:privatelink/endpoint:Endpoint": "Endpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "proximity/placementGroup",
  "fqn": "pulumi_azure.proximity",
  "classes": {
   "azure:proximity/placementGroup:PlacementGroup": "PlacementGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "purview/account",
  "fqn": "pulumi_azure.purview",
  "classes": {
   "azure:purview/account:Account": "Account"
  }
 },
 {
  "pkg": "azure",
  "mod": "recoveryservices/vault",
  "fqn": "pulumi_azure.recoveryservices",
  "classes": {
   "azure:recoveryservices/vault:Vault": "Vault"
  }
 },
 {
  "pkg": "azure",
  "mod": "redis/cache",
  "fqn": "pulumi_azure.redis",
  "classes": {
   "azure:redis/cache:Cache": "Cache"
  }
 },
 {
  "pkg": "azure",
  "mod": "redis/enterpriseCluster",
  "fqn": "pulumi_azure.redis",
  "classes": {
   "azure:redis/enterpriseCluster:EnterpriseCluster": "EnterpriseCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "redis/enterpriseDatabase",
  "fqn": "pulumi_azure.redis",
  "classes": {
   "azure:redis/enterpriseDatabase:EnterpriseDatabase": "EnterpriseDatabase"
  }
 },
 {
  "pkg": "azure",
  "mod": "redis/firewallRule",
  "fqn": "pulumi_azure.redis",
  "classes": {
   "azure:redis/firewallRule:FirewallRule": "FirewallRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "redis/linkedServer",
  "fqn": "pulumi_azure.redis",
  "classes": {
   "azure:redis/linkedServer:LinkedServer": "LinkedServer"
  }
 },
 {
  "pkg": "azure",
  "mod": "relay/hybridConnection",
  "fqn": "pulumi_azure.relay",
  "classes": {
   "azure:relay/hybridConnection:HybridConnection": "HybridConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "relay/namespace",
  "fqn": "pulumi_azure.relay",
  "classes": {
   "azure:relay/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "azure",
  "mod": "role/assignment",
  "fqn": "pulumi_azure.role",
  "classes": {
   "azure:role/assignment:Assignment": "Assignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "role/definition",
  "fqn": "pulumi_azure.role",
  "classes": {
   "azure:role/definition:Definition": "Definition"
  }
 },
 {
  "pkg": "azure",
  "mod": "search/service",
  "fqn": "pulumi_azure.search",
  "classes": {
   "azure:search/service:Service": "Service"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/advancedThreatProtection",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/advancedThreatProtection:AdvancedThreatProtection": "AdvancedThreatProtection"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/assessment",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/assessment:Assessment": "Assessment"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/assessmentMetadata",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/assessmentMetadata:AssessmentMetadata": "AssessmentMetadata"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/assessmentPolicy",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/assessmentPolicy:AssessmentPolicy": "AssessmentPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/autoProvisioning",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/autoProvisioning:AutoProvisioning": "AutoProvisioning"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/automation",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/automation:Automation": "Automation"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/contact",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/contact:Contact": "Contact"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/serverVulnerabilityAssessment",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/serverVulnerabilityAssessment:ServerVulnerabilityAssessment": "ServerVulnerabilityAssessment"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/setting",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/setting:Setting": "Setting"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/subscriptionPricing",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/subscriptionPricing:SubscriptionPricing": "SubscriptionPricing"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/workspace",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/workspace:Workspace": "Workspace"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/alertRuleFusion",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/alertRuleFusion:AlertRuleFusion": "AlertRuleFusion"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/alertRuleMachineLearningBehaviorAnalytics",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/alertRuleMachineLearningBehaviorAnalytics:AlertRuleMachineLearningBehaviorAnalytics": "AlertRuleMachineLearningBehaviorAnalytics"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/alertRuleMsSecurityIncident",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/alertRuleMsSecurityIncident:AlertRuleMsSecurityIncident": "AlertRuleMsSecurityIncident"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/alertRuleScheduled",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/alertRuleScheduled:AlertRuleScheduled": "AlertRuleScheduled"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorAwsCloudTrail",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorAwsCloudTrail:DataConnectorAwsCloudTrail": "DataConnectorAwsCloudTrail"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorAzureActiveDirectory",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorAzureActiveDirectory:DataConnectorAzureActiveDirectory": "DataConnectorAzureActiveDirectory"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorAzureAdvancedThreadProtection",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorAzureAdvancedThreadProtection:DataConnectorAzureAdvancedThreadProtection": "DataConnectorAzureAdvancedThreadProtection"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorAzureSecurityCenter",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorAzureSecurityCenter:DataConnectorAzureSecurityCenter": "DataConnectorAzureSecurityCenter"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorMicrosoftCloudAppSecurity",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorMicrosoftCloudAppSecurity:DataConnectorMicrosoftCloudAppSecurity": "DataConnectorMicrosoftCloudAppSecurity"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorMicrosoftDefenderAdvancedThreatProtection",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorMicrosoftDefenderAdvancedThreatProtection:DataConnectorMicrosoftDefenderAdvancedThreatProtection": "DataConnectorMicrosoftDefenderAdvancedThreatProtection"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorOffice365",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorOffice365:DataConnectorOffice365": "DataConnectorOffice365"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorThreatIntelligence",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorThreatIntelligence:DataConnectorThreatIntelligence": "DataConnectorThreatIntelligence"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicebus/namespace",
  "fqn": "pulumi_azure.servicebus",
  "classes": {
   "azure:servicebus/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicebus/namespaceAuthorizationRule",
  "fqn": "pulumi_azure.servicebus",
  "classes": {
   "azure:servicebus/namespaceAuthorizationRule:NamespaceAuthorizationRule": "NamespaceAuthorizationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicebus/namespaceDisasterRecoveryConfig",
  "fqn": "pulumi_azure.servicebus",
  "classes": {
   "azure:servicebus/namespaceDisasterRecoveryConfig:NamespaceDisasterRecoveryConfig": "NamespaceDisasterRecoveryConfig"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicebus/namespaceNetworkRuleSet",
  "fqn": "pulumi_azure.servicebus",
  "classes": {
   "azure:servicebus/namespaceNetworkRuleSet:NamespaceNetworkRuleSet": "NamespaceNetworkRuleSet"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicebus/queue",
  "fqn": "pulumi_azure.servicebus",
  "classes": {
   "azure:servicebus/queue:Queue": "Queue"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicebus/queueAuthorizationRule",
  "fqn": "pulumi_azure.servicebus",
  "classes": {
   "azure:servicebus/queueAuthorizationRule:QueueAuthorizationRule": "QueueAuthorizationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicebus/subscription",
  "fqn": "pulumi_azure.servicebus",
  "classes": {
   "azure:servicebus/subscription:Subscription": "Subscription"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicebus/subscriptionRule",
  "fqn": "pulumi_azure.servicebus",
  "classes": {
   "azure:servicebus/subscriptionRule:SubscriptionRule": "SubscriptionRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicebus/topic",
  "fqn": "pulumi_azure.servicebus",
  "classes": {
   "azure:servicebus/topic:Topic": "Topic"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicebus/topicAuthorizationRule",
  "fqn": "pulumi_azure.servicebus",
  "classes": {
   "azure:servicebus/topicAuthorizationRule:TopicAuthorizationRule": "TopicAuthorizationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicefabric/cluster",
  "fqn": "pulumi_azure.servicefabric",
  "classes": {
   "azure:servicefabric/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicefabric/meshApplication",
  "fqn": "pulumi_azure.servicefabric",
  "classes": {
   "azure:servicefabric/meshApplication:MeshApplication": "MeshApplication"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicefabric/meshLocalNetwork",
  "fqn": "pulumi_azure.servicefabric",
  "classes": {
   "azure:servicefabric/meshLocalNetwork:MeshLocalNetwork": "MeshLocalNetwork"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicefabric/meshSecret",
  "fqn": "pulumi_azure.servicefabric",
  "classes": {
   "azure:servicefabric/meshSecret:MeshSecret": "MeshSecret"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicefabric/meshSecretValue",
  "fqn": "pulumi_azure.servicefabric",
  "classes": {
   "azure:servicefabric/meshSecretValue:MeshSecretValue": "MeshSecretValue"
  }
 },
 {
  "pkg": "azure",
  "mod": "signalr/service",
  "fqn": "pulumi_azure.signalr",
  "classes": {
   "azure:signalr/service:Service": "Service"
  }
 },
 {
  "pkg": "azure",
  "mod": "siterecovery/fabric",
  "fqn": "pulumi_azure.siterecovery",
  "classes": {
   "azure:siterecovery/fabric:Fabric": "Fabric"
  }
 },
 {
  "pkg": "azure",
  "mod": "siterecovery/networkMapping",
  "fqn": "pulumi_azure.siterecovery",
  "classes": {
   "azure:siterecovery/networkMapping:NetworkMapping": "NetworkMapping"
  }
 },
 {
  "pkg": "azure",
  "mod": "siterecovery/protectionContainer",
  "fqn": "pulumi_azure.siterecovery",
  "classes": {
   "azure:siterecovery/protectionContainer:ProtectionContainer": "ProtectionContainer"
  }
 },
 {
  "pkg": "azure",
  "mod": "siterecovery/protectionContainerMapping",
  "fqn": "pulumi_azure.siterecovery",
  "classes": {
   "azure:siterecovery/protectionContainerMapping:ProtectionContainerMapping": "ProtectionContainerMapping"
  }
 },
 {
  "pkg": "azure",
  "mod": "siterecovery/replicatedVM",
  "fqn": "pulumi_azure.siterecovery",
  "classes": {
   "azure:siterecovery/replicatedVM:ReplicatedVM": "ReplicatedVM"
  }
 },
 {
  "pkg": "azure",
  "mod": "siterecovery/replicationPolicy",
  "fqn": "pulumi_azure.siterecovery",
  "classes": {
   "azure:siterecovery/replicationPolicy:ReplicationPolicy": "ReplicationPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "sql/activeDirectoryAdministrator",
  "fqn": "pulumi_azure.sql",
  "classes": {
   "azure:sql/activeDirectoryAdministrator:ActiveDirectoryAdministrator": "ActiveDirectoryAdministrator"
  }
 },
 {
  "pkg": "azure",
  "mod": "sql/database",
  "fqn": "pulumi_azure.sql",
  "classes": {
   "azure:sql/database:Database": "Database"
  }
 },
 {
  "pkg": "azure",
  "mod": "sql/elasticPool",
  "fqn": "pulumi_azure.sql",
  "classes": {
   "azure:sql/elasticPool:ElasticPool": "ElasticPool"
  }
 },
 {
  "pkg": "azure",
  "mod": "sql/failoverGroup",
  "fqn": "pulumi_azure.sql",
  "classes": {
   "azure:sql/failoverGroup:FailoverGroup": "FailoverGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "sql/firewallRule",
  "fqn": "pulumi_azure.sql",
  "classes": {
   "azure:sql/firewallRule:FirewallRule": "FirewallRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "sql/sqlServer",
  "fqn": "pulumi_azure.sql",
  "classes": {
   "azure:sql/sqlServer:SqlServer": "SqlServer"
  }
 },
 {
  "pkg": "azure",
  "mod": "sql/virtualNetworkRule",
  "fqn": "pulumi_azure.sql",
  "classes": {
   "azure:sql/virtualNetworkRule:VirtualNetworkRule": "VirtualNetworkRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "stack/hciCluster",
  "fqn": "pulumi_azure.stack",
  "classes": {
   "azure:stack/hciCluster:HciCluster": "HciCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/account",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/account:Account": "Account"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/accountNetworkRules",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/accountNetworkRules:AccountNetworkRules": "AccountNetworkRules"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/blob",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/blob:Blob": "Blob"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/blobInventoryPolicy",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/blobInventoryPolicy:BlobInventoryPolicy": "BlobInventoryPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/container",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/container:Container": "Container"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/customerManagedKey",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/customerManagedKey:CustomerManagedKey": "CustomerManagedKey"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/dataLakeGen2Filesystem",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/dataLakeGen2Filesystem:DataLakeGen2Filesystem": "DataLakeGen2Filesystem"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/dataLakeGen2Path",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/dataLakeGen2Path:DataLakeGen2Path": "DataLakeGen2Path"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/encryptionScope",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/encryptionScope:EncryptionScope": "EncryptionScope"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/managementPolicy",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/managementPolicy:ManagementPolicy": "ManagementPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/queue",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/queue:Queue": "Queue"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/share",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/share:Share": "Share"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/shareDirectory",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/shareDirectory:ShareDirectory": "ShareDirectory"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/shareFile",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/shareFile:ShareFile": "ShareFile"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/sync",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/sync:Sync": "Sync"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/syncCloudEndpoint",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/syncCloudEndpoint:SyncCloudEndpoint": "SyncCloudEndpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/syncGroup",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/syncGroup:SyncGroup": "SyncGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/table",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/table:Table": "Table"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/tableEntity",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/tableEntity:TableEntity": "TableEntity"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/zipBlob",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/zipBlob:ZipBlob": "ZipBlob"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/functionJavaScriptUDF",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/functionJavaScriptUDF:FunctionJavaScriptUDF": "FunctionJavaScriptUDF"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/job",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/job:Job": "Job"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/outputBlob",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/outputBlob:OutputBlob": "OutputBlob"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/outputEventHub",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/outputEventHub:OutputEventHub": "OutputEventHub"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/outputMssql",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/outputMssql:OutputMssql": "OutputMssql"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/outputServiceBusQueue",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/outputServiceBusQueue:OutputServiceBusQueue": "OutputServiceBusQueue"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/outputServicebusTopic",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/outputServicebusTopic:OutputServicebusTopic": "OutputServicebusTopic"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/referenceInputBlob",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/referenceInputBlob:ReferenceInputBlob": "ReferenceInputBlob"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/streamInputBlob",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/streamInputBlob:StreamInputBlob": "StreamInputBlob"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/streamInputEventHub",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/streamInputEventHub:StreamInputEventHub": "StreamInputEventHub"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/streamInputIotHub",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/streamInputIotHub:StreamInputIotHub": "StreamInputIotHub"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/firewallRule",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/firewallRule:FirewallRule": "FirewallRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/managedPrivateEndpoint",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/managedPrivateEndpoint:ManagedPrivateEndpoint": "ManagedPrivateEndpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/roleAssignment",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/roleAssignment:RoleAssignment": "RoleAssignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/sparkPool",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/sparkPool:SparkPool": "SparkPool"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/sqlPool",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/sqlPool:SqlPool": "SqlPool"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/workspace",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/workspace:Workspace": "Workspace"
  }
 },
 {
  "pkg": "azure",
  "mod": "trafficmanager/endpoint",
  "fqn": "pulumi_azure.trafficmanager",
  "classes": {
   "azure:trafficmanager/endpoint:Endpoint": "Endpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "trafficmanager/profile",
  "fqn": "pulumi_azure.trafficmanager",
  "classes": {
   "azure:trafficmanager/profile:Profile": "Profile"
  }
 },
 {
  "pkg": "azure",
  "mod": "waf/policy",
  "fqn": "pulumi_azure.waf",
  "classes": {
   "azure:waf/policy:Policy": "Policy"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "azure",
  "token": "pulumi:providers:azure",
  "fqn": "pulumi_azure",
  "class": "Provider"
 }
]
"""
)
